close all
clear all
clc

Rgas=8.314;
T0=273.15+236;
P0=101.3E3;
ndot0=5/3600;
xA0=.5;
Vdot0=ndot0*Rgas*T0/P0;
ndotA0=P0*xA0*Vdot0/(Rgas*T0);

Dia=.05;
Area=pi()*Dia^2/4;
Length=1;
VrTotal=Area*Length;

Vrspan=linspace(0,VrTotal,200);
Init0=[ndotA0 0 0 0 0];

[Vr, n]=ode23s(@ddt, Vrspan, Init0, [], T0, P0, ndot0, Vdot0, ndotA0);

for i=1:length(Vr)
 Vdot(i)=sum(n(i,1:5))*Rgas*T0/P0;
end
Length=Vr./Area;
GlobalConv=((Init0(1)-n(:,1))./Init0(1))*100;

for i=1:length(Vr)
    if GlobalConv(i)>95
        Vr95=Vr(i);
        Vdot95=Vdot(i);
        Length95=Length(i);
        break
    end
end

Tau95=Vr95/Vdot95;

fprintf('95%% of formic acid conversion is achieved at the space-time of %.1f s\n\n', Tau95);

figure 
hold on
plot(Length,n*3600)
TextBox1={'CH_3OH', 'H_2O','CO', 'H_2','CO_2'};
legend(TextBox1)
xlabel('Reactor length [m]')
ylabel('Molar Flow [mol/h]');
title('Molar Flow Profile');
hold off

figure 
hold on
plot(Length, GlobalConv)
plot([0 Length95 Length95],[95 95 0], 'k--')
TextBox2={'Conversion', '95% Conversion'};
legend(TextBox2)
xlabel('Reactor length [m]')
ylabel('Conversion [%]');
title('Conversion Profile');
hold off

figure 
hold on
plot(Length, Vdot)
xlabel('Reactor length [m]')
ylabel('Volumetric Flow Rate [m^3/s]');
title('Volumetric Flow Rate Profile');
hold off