close all
clear all
clc

Data=load('ExpData.txt');
Time=Data(:,1);
Conc=Data(:,2);

Conc0=Conc(1);        % initial concentration of methanol               
C0triphenyl=0.106;    % initial concentration of triphenyl 

fObjFun=@(k)ObjFun(k, Time, Conc, Conc0, C0triphenyl);
[k,~,resid,~,~,~,J]=lsqnonlin(fObjFun, .01, 0, 10);     % calls the minimization function 

ci=nlparci(k,resid, 'jacobian', J);                     % calculates the parameter estimation error within a 95% confidence interval

fprintf('Fitted reaction constant: %.3f [units]\t Estimation Error=%.2f%%\n\n', k, (k-ci(1))/k*100);      % check in the command prompt for the result

[t,c]=ode23s(@rate, Time, Conc0, [], k, Conc0, C0triphenyl);                            % simulates the curve using the fitting parameter using the same Time domain as the experimental data

SQE=sum((c-Conc).^2);                   % calculates the sum of the differences squared
SQA=sum((c-mean(Conc)).^2);             % calculates the sum of the differences between the average and the simulated data
R2=(1-SQE/SQA)*100;                     % calculates the degree of explanation

fprintf('Degree of explanation= %.2f%%\n\n', R2);

timespan=linspace(Time(1),Time(end),100);
[t,c]=ode23s(@rate, timespan, Conc0, [], k, Conc0, C0triphenyl);             % simulates the curve using the fitting parameter using a time domain with more points

figure
hold on
plot(t,c,'b')
plot(Time,Conc,'bo')
box on
TextBox1={'Methanol Fitted', 'Methanol Experimental'};
legend(TextBox1)
xlabel('Time [min]')
ylabel('Concentration [mol/L]');
title('Data fitting')
hold off

SensInterval=linspace(0,6*k,100);   % interval for sensitivy plot 

for i=1:length(SensInterval) 
    Sensitivity(i)=sum(ObjFun(SensInterval(i), Time, Conc, Conc0, C0triphenyl).^2);
end

figure
hold on
plot(SensInterval, Sensitivity)
xlabel('k_r_e_f')
ylabel('Objective function [mol/L]');
xlim([0 max(SensInterval)])
title('Sensitivity plot')
hold off