close all
clear all
clc

Data30=load('Temp30.txt');
Data40=load('Temp40.txt');
Data50=load('Temp50.txt');
Data60=load('Temp60.txt');

Time=Data30(:,1);
ExpConc30=Data30(:,2);
ExpConc40=Data40(:,2);
ExpConc50=Data50(:,2);
ExpConc60=Data60(:,2);
ExpConc=[ExpConc30 ExpConc40 ExpConc50 ExpConc60];

Temp=[30 40 50 60];
Temp=273.15+Temp;
Rgas=8.314;

k0=.1;

for i=1:length(Temp)
    fObjFun=@(k) ObjFun(k,i, 1, Time, ExpConc);
    [k(i),~,resid(:,i),~,~,~,J(:,i)]=lsqnonlin(fObjFun,k0, 0, 10);
end

%statistical calculations 
for i=1:length(Temp)
    [t,c]=ode23s(@Rates, Time, ExpConc(1,i), [], k(i), 1);
    SQE(i)=sum((ExpConc(:,i)-c).^2);
    SQA(i)=sum((c-mean(ExpConc(:,i))).^2);
    R2(i)=(1-SQE(i)/SQA(i))*100;
    ci(i,:)=nlparci(k(i), resid(:,i), 'jacobian', J(:,i));    
end

for i=1:length(Temp)
    fprintf('R^2 (@%ioC)=%.2f%%\t\tk(@%ioC)=%.2e 1/s\t\tEstimation error(%%)=%.2f\n',Temp(i)-273.15,R2(i), Temp(i)-273.15, k(i),(k(i)-ci(i,1))/k(i)*100);
end

lnk=[log(k)];
TempInv=1./(Temp);

KinParam=polyfit(TempInv, lnk, 1);

Ea=-Rgas/1000*KinParam(1);
A=exp(KinParam(2));

figure 
hold on

plot(TempInv, polyval(KinParam,TempInv), 'b')
plot(TempInv, lnk, 'bo')

xlabel('1/T')
ylabel('ln(k)');
title('Arrhenius Plot');

hold off

fprintf('\nPre-exponential factor: %.2e m^3/s/mol\nActivation energy: %.2f kJ/mol\n', A, Ea);

t=[];
c=[];
timespan=linspace(Time(1), Time(end), 100);
for i=1:length(Temp)
    [t,c(:,i)]=ode23s(@Rates, timespan, ExpConc(1,i), [], k(i), 1);
end

figure
hold on
plot(t,c(:,1),'k',t,c(:,2),'r',t,c(:,3),'g',t,c(:,4),'b')
plot(Time,ExpConc(:,1),'ko',Time,ExpConc(:,2),'ro',Time,ExpConc(:,3),'go',Time,ExpConc(:,4),'bo')
legend({'Temperature 30^oC', 'Temperature  40^oC', 'Temperature  50^oC', 'Temperature  60^oC'});
xlabel('Time [s]')
ylabel('Concentration [mmol/L]');
title('Data fitting');
hold off