close all
clear all
clc

Data30=load('Temp30.txt');
Data40=load('Temp40.txt');
Data50=load('Temp50.txt');
Data60=load('Temp60.txt');

Time=Data30(:,1);
ExpConc30=Data30(:,2);
ExpConc40=Data40(:,2);
ExpConc50=Data50(:,2);
ExpConc60=Data60(:,2);
ExpConc=[ExpConc30 ExpConc40 ExpConc50 ExpConc60];

Temp=[30 40 50 60];
Temp=273.15+Temp;
Tref=mean(Temp);

ExpConc0=ExpConc(1,:);
Rgas=8.314;

k0=.01;
Ea0=50;

fObjFunE=@(kin)ObjFunE(kin, ExpConc, Time, ExpConc0, Tref, Temp);
[Parameters,~,resid,~,~,~,J]=lsqnonlin(fObjFunE,[k0 Ea0], [0 0], [10 1000]);

[t,c]=ode23s(@RatesE, Time, ExpConc0, [], Parameters, Tref, Temp);
A=Parameters(1)/exp(-Parameters(2)*1E3/Rgas/Tref);

%statistical calculations
SQE=sum(sum((c-ExpConc).^2));
SQA=sum(sum((c-mean(mean(ExpConc))).^2));
R2=(1-SQE/SQA)*100;
ci=nlparci(Parameters, resid, 'jacobian', J); 

fprintf('k(@%ioC)=%.2e m^3/mol/s\t\tEstimation error=%.2f%%\n', Tref-273.15, Parameters(1), (Parameters(1)-ci(1,1))/Parameters(1)*100);
fprintf('Activation energy=%.2f kJ/mol\t\tEstimation error=%.2f%%\n', Parameters(2), (Parameters(2)-ci(2,1))/Parameters(2)*100)
fprintf('Degree of explanation= %.2f%%\n\n', R2);
fprintf('Pre-exponential factor: %.2e m^3/s/mol\n\n', A);

timespan=linspace(Time(1), Time(end), 100);

t=[];
c=[];
[t,c]=ode23s(@RatesE, timespan, ExpConc0, [], Parameters, Tref, Temp);

figure
hold on
plot(t,c(:,1),'k',t,c(:,2),'r',t,c(:,3),'g',t,c(:,4),'b')
plot(Time,ExpConc(:,1),'ko',Time,ExpConc(:,2),'ro',Time,ExpConc(:,3),'go',Time,ExpConc(:,4),'bo')
legend({'Temperature 30^oC', 'Temperature  40^oC', 'Temperature  50^oC', 'Temperature  60^oC'});
xlabel('Time [s]')
ylabel('Concentration [mmol/L]');
title('Data fitting');
hold off