%Non-linear regression

clear all 
close all 
clc

Rgas=8.314;

ExpData120=load('120.txt');
ExpData125=load('125.txt');
ExpData130=load('130.txt');
ExpData135=load('135.txt');
ExpData142=load('142.txt');
ExpData147=load('147.txt');
ExpData150=load('150.txt');

Temp=[120 125 130 135 142 147 150];
Temp=Temp+273.15;
Tref=mean(Temp);
Time=ExpData120(:,1).'.*60;
ExpConc=[ExpData120(:,2:end) ExpData125(:,2:end) ExpData130(:,2:end) ExpData135(:,2:end) ExpData142(:,2:end) ExpData147(:,2:end) ExpData150(:,2:end)];

[~,nComp]=size(ExpData120);
nComp=nComp-1;
Conc0=ExpConc(1,:);

InitGuess=[1E-6 1 1E-6 1 1E-6 1 1E-6 1];

options.Algorithm = 'levenberg-marquardt';
fObjFun=@(kin)ObjFun(kin, Time, Conc0, ExpConc, nComp, Temp, Tref);
[Parameters,~,resid,~,~,~,J]=lsqnonlin(fObjFun, InitGuess, [], [], options);

for i=1:length(Conc0)/nComp
   [t,c(:,6*(i-1)+1:6*i)]=ode23s(@ddt, Time, Conc0(6*(i-1)+1:6*i), [], Parameters, Temp(i), Tref);
end

%statistical calculations
SQE=sum(sum((ExpConc-c).^2));
meanConc=mean(mean(ExpConc));
SQA=sum(sum((meanConc-c).^2));
R2=(1-SQE/SQA)*100;
ci=nlparci(Parameters, resid, 'jacobian', J);

kref(1:4)=Parameters(1:2:7);
Ea(1:4)=Parameters(2:2:8);
krefCI=ci(1:2:7,1);
EaCI=ci(2:2:8,1);

for i=1:length(kref)
    fprintf('k%i(Tref)=%.2e\tEstimation error=%.2f%%\t\tEa%i=%.2f kJ/mol\tEstimation error=%.2f%%\n', i, kref(i), (kref(i)-krefCI(i))./kref(i)*100, i, Ea(i), (Ea(i)-EaCI(i))/Ea(i)*100);
end
fprintf('Tref=%.2foC\n\n', Tref-273.15);

A=kref./exp(-Ea.*1E3./Rgas./Tref)*60;

for i=1:4
   fprintf('Pre-exponential factor %i= %.2e 1/min\n', i, A(i)); 
end
fprintf('Degree of explanation (R^2)= %.2f %%\n', R2);

timespan=linspace(Time(1), Time(end), 100);

c=[];
for i=1:length(Conc0)/nComp
    [t,c(:,6*(i-1)+1:6*i)]=ode23s(@ddt, timespan, Conc0(6*(i-1)+1:6*i), [], Parameters, Temp(i), Tref);
    figure (i)
    hold on
    plot(t/60,c(:,6*(i-1)+1),'k', t/60,c(:,6*(i-1)+2),'b', t/60, c(:,6*(i-1)+3),'r',t/60, c(:,6*(i-1)+4),'g',t/60, c(:,6*(i-1)+5),'y',t/60, c(:,6*(i-1)+6),'k')
    plot(Time/60,ExpConc(:,6*(i-1)+1),'ko', Time/60,ExpConc(:,6*(i-1)+2),'bo', Time/60, ExpConc(:,6*(i-1)+3),'ro',Time/60, ExpConc(:,6*(i-1)+4),'go',Time/60, ExpConc(:,6*(i-1)+5),'yo',Time/60, ExpConc(:,6*(i-1)+6),'ko')
    xlabel('Time [min]')
    ylabel('Concentration [mol/kg]')
    title(['Experiment @', num2str(Temp(i)-273.15),'^oC']);
    TextBox={'AT', 'AC', 'PT', 'PC', 'ST', 'SC'};
    legend(TextBox)
    hold off
end