close all
clear all
clc

Data90=load('Exp90.txt');
Data110=load('Exp110.txt');
Data120=load('Exp120.txt');
Data130=load('Exp130.txt');

Conc90=Data90(:,2);
Conc110=Data110(:,2);
Conc120=Data120(:,2);
Conc130=Data130(:,2);
Conc=[Conc90 Conc110 Conc120 Conc130];

Time=60.*Data90(:,1);

Temp=[90 110 120 130];
Temp=Temp+273.15;
Tref=mean(Temp);
Rgas=8.314;

Init0=[0 0 0 0];

kp0=1E-5;
Eap0=50;
k10=1E-5;
Ea10=60;

InitGuess=[kp0 Eap0 k10 Ea10];

lb=[0 0 0 0];
ub=[10 1000 10 1000];

fObjFun=@(kin)ObjFun(kin, Time, Conc, Init0, Temp, Tref);
Parameter=lsqnonlin(fObjFun, InitGuess, lb, ub);

[t,c]=ode23t(@rate, Time, Init0, [], Parameter, Temp, Tref);

SQE=sum(sum((Conc-c).^2));
Average=mean(mean(Conc));
SQA=sum(sum((Conc-Average).^2));
R2=(1-SQE/SQA)*100;

Eap=Parameter(2);
Ap=Parameter(1)/exp(-Eap*1E3/Rgas/Tref);
Ea1=Parameter(4);
A1=Parameter(3)/exp(-Ea1*1E3/Rgas/Tref);

fprintf('Pre-exponential factor kp=%.2e\nActivation energy kp= %.2f kJ/mol\n\n', Ap, Eap);
fprintf('Pre-exponential factor k1= %.2e\nActivation energy k1= %.2f kJ/mol\n\n', A1, Ea1);
fprintf('Degree of explanation= %.2f%%\n\n',R2);

[t,c]=ode23t(@rate, [Time(1) Time(end)], Init0, [], Parameter, Temp, Tref);

Time=Time/60;
t=t/60;

figure 
hold on 

plot(t,c(:,1), 'r', Time, Conc(:,1), 'ro');
plot(t,c(:,2), 'b', Time, Conc(:,2), 'bo');
plot(t,c(:,3), 'g', Time, Conc(:,3), 'go');
plot(t,c(:,4), 'k', Time, Conc(:,4), 'ko');

box on
TextBox1={'Fitted 90^oC', 'Exp. 90^oC','Fitted 110^oC', 'Exp. 110^oC','Fitted 120^oC', 'Exp. 120^oC','Fitted 130^oC', 'Exp. 130^oC'};
legend(TextBox1)

xlim([0 Time(end)]);

xlabel('Time [min]')
ylabel('MCA mol fraction');
title('Data fitting');

hold off