clear all 
close all
clc

PressureData=load('PartialPressures.txt');
pH2=PressureData(:,1);
pT=PressureData(:,2);

Rate120=load('R120.txt');
Rate135=load('R135.txt');
Rate151=load('R151.txt');
Rate171=load('R171.txt');
Rate186=load('R186.txt');
Rate200=load('R200.txt');

Rates=[Rate120 Rate135 Rate151 Rate171 Rate186 Rate200];

Temp=[120 135 151 171 186 200];  % experimental temperature in Celsius degrees
Temp=Temp+273.15;       % transforms the temperature to Kelvin

Rates=10^6.*Rates;
pH2=1E5.*pH2;           % converts hydrogen pressure to Pa
pT=1E5.*pT;             % converts toluene pressure to Pa
Tref=mean(Temp);        % defines a reference temperature
Rgas=8.314;            

k0=1E3;
Ea0=100;
m0=1;
n0=-1;

Init0=[k0 Ea0 m0 n0];

options.MaxFunEvals = 4000;
fObjFun=@(kin)ObjFun1(kin, pH2, pT, Temp, Tref, Rates);
Parameter=lsqnonlin(fObjFun, [k0 Ea0 m0 n0], [], [], options); 

A=Parameter(1)/(exp(-Parameter(2)*1E3/Rgas/Tref));
Ea=Parameter(2);
m=Parameter(3);
n=Parameter(4);

Rcalc=exp(R1eval(Parameter, pH2, pT, Temp, Tref, Rates));

Average=mean(mean(Rcalc));

SQE=sum(sum((Rcalc-Rates).^2));
SQA=sum(sum((Rcalc-Average).^2));
R2=(1-SQE/SQA)*100;

fprintf('Rate=k*pH^m*pT^n\n\n')
fprintf('Reaction rate\nPre-exponential factor = %.2e\nActivation energy: %.2f kJ/mol\n\n',A, Ea);
fprintf('Exponent ''m''= %.2e\n', m);
fprintf('Exponent ''n''= %.2e\n', n);
fprintf('Degree of explanation: %.2f%%\n', R2);

hold on

plot(Rates, Rcalc, 'bo');
plot([0 max(max(Rates))],[0 max(max(Rates))], 'k');

xlim([min(min(Rates)) max(max(Rates))]);
ylim([min(min(Rates)) max(max(Rates))]);

xlabel('Experimental value')
ylabel('Estimated value');
title('Parity plot (Experimental vs. Simulated)');

hold off