clear all 
close all
clc

PressureData=load('PartialPressures.txt');
pH2=PressureData(:,1);
pT=PressureData(:,2);

Rate120=load('R120.txt');
Rate135=load('R135.txt');
Rate151=load('R151.txt');
Rate171=load('R171.txt');
Rate186=load('R186.txt');
Rate200=load('R200.txt');

Rates=[Rate120 Rate135 Rate151 Rate171 Rate186 Rate200];

Temp=[120 135 151 171 186 200];  % experimental temperature in Celsius degrees
Temp=Temp+273.15;       % transforms the temperature to Kelvin

Rates=10^6.*Rates;
pH2=1E5.*pH2;           % converts hydrogen pressure to Pa
pT=1E5.*pT;             % converts toluene pressure to Pa
Tref=mean(Temp);        % defines a reference temperature
Rgas=8.314;             

k0=923;
Ea0=75;
KT0=1.5E-3;
KH0=2.5E-3;
Init0=[k0 Ea0 KT0 KH0];
lb=[0 0 0 0];
ub=[1E9 1E3 1E3 1E3];

fObjFun2=@(kin)ObjFun2(kin, pH2, pT, Temp, Tref, Rates);
Parameter=lsqnonlin(fObjFun2, Init0, lb, ub); 

A=Parameter(1)/(exp(-Parameter(2)*1E3/Rgas/Tref));
Ea=Parameter(2);
KT=Parameter(3);
KH=Parameter(4);

Rcalc=R2eval(Parameter, pH2, pT, Temp, Tref, Rates);

Rcalc=Rcalc.^(-7);

Average=mean(mean(Rcalc));

SQE=sum(sum((Rcalc-Rates).^2));
SQA=sum(sum((Rcalc-Average).^2));
R2=(1-SQE/SQA)*100;

fprintf('Reaction rate\nPre-exponential factor = %.2e\nActivation energy: %.2f kJ/mol\n\n',A, Ea);
fprintf('Toluene adsorption constant= %.2e\n', KT);
fprintf('Hydrogen adsorption constant= %.2e\n', KH);
fprintf('Degree of explanation: %.2f%%\n', R2);

hold on

plot(Rates, Rcalc, 'bo');
plot([0 max(max(Rates))],[0 max(max(Rates))], 'k');

xlim([min(min(Rates)) max(max(Rates))]);
ylim([min(min(Rates)) max(max(Rates))]);

xlabel('Experimental value')
ylabel('Estimated value');
title('Parity plot (Experimental vs. Simulated)');

hold off