close all
clear all
clc

Data20=load('Conc20.txt');
Data40=load('Conc40.txt');
Data60=load('Conc60.txt');
Data80=load('Conc80.txt');

C20=Data20(:,2:end);
C40=Data40(:,2:end);
C60=Data60(:,2:end);
C80=Data80(:,2:end);

Time=Data20(:,1);
Init0=C20(1,:);

pH2=[20 40 60 80];
Henry=8.2E-3;
cH2=Henry*pH2;

Conc=[C20 C40 C60 C80];
Guess0=[1E-3 1E-3 1E-3 1E-3 1E-3];

fObjFun=@(P)ObjFun(P,pH2,Conc, Time, Init0, cH2);
[Parameters,~,resid,~,~,~,J]=lsqnonlin(fObjFun, Guess0);

ci=nlparci(Parameters, resid, 'jacobian', J);

for i=1:length(Parameters)
    Error(i)=(ci(i,2)-Parameters(i))/Parameters(i)*100;
end

k3p=Parameters(1);
k5p=Parameters(2);
k7p=Parameters(3);
KA=Parameters(4);
KH2=Parameters(5);

for i=1:length(pH2)
    [t,c(:,4*(i-1)+1:4*i)]=ode23s(@ddt, Time, Init0, [], pH2(i), Parameters, cH2(i));
end

SQE=sum((Conc-c).^2);
SQA=sum(((mean(mean(Conc))-c)).^2);
R2=(1-SQE/SQA)*100;

fprintf('k''3=%.2e mol*L^(3/2)/(mol^3/2*g*min)\tEstimation error=%.2f%%\n',k3p, Error(1));
fprintf('k''5=%.2e mol*L^(3/2)/(mol^3/2*g*min)\tEstimation error=%.2f%%\n', k5p, Error(2));
fprintf('k''7=%.2e L/(g*min)\tEstimation error=%.2f%%\n', k7p, Error(3));
fprintf('KA=%.2e L/mol\tEstimation error=%.2f%%\n', KA, Error(4));
fprintf('KH2=%.2e L/mol\tEstimation error=%.2f%%\n', KH2, Error(5));
fprintf('Degree of explanation (R^2)=%.2f%%\n\n',R2);

timespan=linspace(Time(1), Time(end), 100);

c=[];
for i=1:length(pH2)
    [t,c(:,4*(i-1)+1:4*i)]=ode23s(@ddt, timespan, Init0, [], pH2(i), Parameters, cH2(i));
end

TextBox1={'A','B','C','D'};

for i=1:length(pH2)
    figure (i)
    hold on
    plot(timespan, c(:,4*(i-1)+1),'k',timespan, c(:,4*(i-1)+2),'b',timespan, c(:,4*(i-1)+3),'r',timespan, c(:,4*(i-1)+4),'g');
    plot(Time,Conc(:,4*(i-1)+1),'ko',Time,Conc(:,4*(i-1)+2),'bo',Time,Conc(:,4*(i-1)+3),'ro',Time,Conc(:,4*(i-1)+4),'go');
    title(['Experiment @', num2str(pH2(i)),' bar']);
    legend(TextBox1);
    xlabel('Time [min]')
    ylabel('Concentration [mol/L]')
    xlim([Time(1) Time(end)])
    hold off
end