close all
clear all
clc

Data=load('Data.txt');

Time=Data(:,1)*60;
TempExp=Data(:,2)+273.15;

Tref=mean(TempExp);       % defines an arbitrary reference temperature
Rgas=8.314;               % ideal gas constant in J/mol/K
 
Ca0=0;                    % initial concentration of A in the reactor
Cb0=0;                    % initial concentration of B in the reactor
T0=TempExp(1,1);           % initial temperature in the reactor

Init0=[Ca0 Cb0 T0]; 

ktref=.05;          % initial guess for the rate constant at the reference temperature 
Ea0=130;            % initial guess of the activation energy in kJ/mol

lb=[0 0];
ub=[10 1000];

fObjFun=@(kin)ObjFun(kin, Time, TempExp, Init0, Tref);
[Parameter,~,resid,~,~,~,J]=lsqnonlin(fObjFun, [ktref Ea0], lb, ub);        % calls the  minimization of the objective fuction 

[t,Cond]=ode23s(@ddt, Time, Init0, [], Parameter, Tref);

SQE=sum((Cond(:,3)-TempExp).^2);
SQA=sum((Cond(:,3)-mean(TempExp)).^2);
R2=(1-SQE/SQA)*100;
ci=nlparci(Parameter, resid, 'jacobian', J);

kref=Parameter(1);
Ea=Parameter(2);

fprintf('k(Tref)=%.2e m3/mol/s\tEstimation error=%.2f%%\t\tTref=%.2foC\n', kref,(kref-ci(1,1))/kref*100,Tref-273.15);
fprintf('Activation energy: %.2f kJ/mol\t\tEstimation error=%.2f%%\n', Ea, (Ea-ci(2,1))/Ea*100);                % prints message in command prompt
fprintf('Degree of explanation: %.2f%%\n', R2);

[t,Cond]=ode23s(@ddt, [Time(1) Time(end)], Init0, [], Parameter, Tref);    % simulates the best fitting curve 

% the following lines arrange the plot of the experimental and fitted
% curves 

figure 

hold on
plot(t/60,Cond(:,3)-273.15)                 % plots the temperature in Celsius and the time in minutes
plot(Time/60, TempExp-273.15, 'bo')         % plots the temperature in Celsius and the time in minutes

box on
TextBox1={'Temperature Fitted', 'Temperature Experimental'};
legend(TextBox1)

xlabel('Time [min]')
ylabel('Temperature (^oC)');
title('Data fitting');

hold off