close all
clear all
clc

Rgas=8.314;
Ea=105E3;
A=1.37E9;
deltaHr=-33.5E3;
rhocp=1980E3;
Temp0=53+273.15;
VL0=5;

cA0=4.55E3;
cB0=5.34E3;
cC0=0;

Init0=[cA0 cB0 cC0 Temp0];

tmax=2*3600;  % two hours of reaction time

Points=300;

Area=linspace(0,50,Points);
timespan=linspace(0, tmax, 3600);

for k=1:length(Area)     % "brute force" method for finding the minumum area
            
            [t,Cond]=ode23s(@ddt, timespan, Init0, [], Area(k), Ea, A, deltaHr, rhocp, Temp0, VL0);

            Tmax=max(Cond(:,4))-273.15;
            
            if Tmax<100
                Conv=(Init0(1)-Cond(:,1))/Init0(1)*100;
                if max(Conv)>95
                    for i=1:length(t)
                        if Conv(i)>=95
                            tmin=t(i);
                            Areamin=Area(k);
                            break
                        end
                    end
                    break
                end
            end            
end

fprintf('Heat transfer Area= %.2f m^2\nTime (95%% Conversion)=%.1f min\n\n',Areamin, tmin/60);

[t,Cond]=ode23s(@ddt, timespan, Init0, [], Areamin, Ea, A, deltaHr, rhocp, Temp0, VL0);

figure
hold on 
plot(t/60,Cond(:,1)/1000,t/60,Cond(:,2)/1000, t/60, Cond(:,3)/1000);
xlim([0 t(end)/60]);
box on
TextBox1={'Maleic Acid', 'Hexanol', 'Maleic Acid Monoester'};
legend(TextBox1)
xlabel('Time [min]')
ylabel('Concentration [mol/L]');
title('Simulation');
hold off

figure 
hold on
plot([0 t(end)/60],[100 100], 'k--')
plot(t/60, Cond(:,4)-273.15);
xlim([0 t(end)/60]);
ylim([min(Cond(:,4))-273.15 105])
box on
TextBox2={'Maximum Allowed Temperature','Temperature'};
legend(TextBox2)
xlabel('Time [min]')
ylabel('Temperature [^oC]');
title('Temperature [^oC] vs. Time [min]');
hold off

figure 
hold on
Aconv=(Init0(1)-Cond(:,1))/Init0(1)*100;
plot([0 tmin/60 tmin/60],[95 95 0], 'k--')
plot(t/60,Aconv)
xlim([0 t(end)/60]);
ylim([0 100])
box on
TextBox3={'95% Conversion','Conversion [%]'};
legend(TextBox3)
xlabel('Time [min]');
ylabel('Conversion [%]');
title('Conversion [%] vs. Time [min]');
hold off