close all
clear all
clc

Rgas=8.314;
Ea=105E3;
A=1.37E9;
deltaHr=-33.5E3;
rhocp=1980E3;
Temp0=53+273.15;
VL0=5;

cA0=4.55E3;
cB0=5.34E3;
cC0=0;

Init0=[cA0 cB0 cC0 Temp0];
A0=10;

[Areamin, tmin]=fmincon(@ObjFun, A0, [],[],[],[], 0, 50, @Const);

timespan=linspace(0,3*3600,3*3600);

[t,Cond]=ode23s(@ddt, timespan, Init0, [], Areamin);

figure
hold on 
plot(t/60,Cond(:,1)/1000,t/60,Cond(:,2)/1000, t/60, Cond(:,3)/1000);
xlim([0 t(end)/60]);
box on
TextBox1={'Maleic Acid', 'Hexanol', 'Maleic Acid Monoester'};
legend(TextBox1)
xlabel('Time [min]')
ylabel('Concentration [mol/L]');
title('Simulation');
hold off

figure 
hold on
plot([0 t(end)/60],[100 100], 'k--')
plot(t/60, Cond(:,4)-273.15);
xlim([0 t(end)/60]);
ylim([min(Cond(:,4))-273.15 105])
box on
TextBox2={'Maximum Allowed Temperature','Temperature'};
legend(TextBox2)
xlabel('Time [min]')
ylabel('Temperature [^oC]');
title('Temperature [^oC] vs. Time [min]');
hold off

figure 
hold on
Conv=(Init0(1)-Cond(:,1))/Init0(1)*100;
fprintf('Heat transfer Area= %.2f m^2\n',Areamin)
fprintf('Reaction time (@95%% Conversion)= %.1f min\n\n', tmin/60)
plot([0 tmin/60 tmin/60],[95 95 0], 'k--')
plot(t/60,Conv)
xlim([0 t(end)/60]);
ylim([0 100])
box on
TextBox3={'95% Conversion','Conversion [%]'};
legend(TextBox3)
xlabel('Time [min]');
ylabel('Conversion [%]');
title('Conversion [%] vs. Time [min]');
hold off

Area=linspace(0,50,100);

for i=1:length(Area)
    ObjFunct(i)=ObjFun(Area(i));
end

figure
plot(Area, ObjFunct/60)
xlim([Area(1) Area(end)])
ylim([40 65])
xlabel('Area [m^2]');
ylabel('Objective Function [min]');
title('Sensitivity Plot');