close all
clear all
clc

T0=290;      
Vr=1;
Vdot=.6E-3;
Tau=Vr/Vdot;
A=1.52E9;
Ea=99E3;
Rgas=8.314;
deltaHr=-33.5E3;
rhocp=1900E3;
Ca0=5E3;

Tdomain=linspace(290,400,200);

for i=1:length(Tdomain)
    Tzero(i)=Tsteady(Tdomain(i),T0, Tau, Ea, A, deltaHr, rhocp, Ca0);      % Calculates the zero function for the temperature domain of 290 to 400 K to check for points it crosses the x axis
end

hold on
title ('Steady-State Temperature zero function');
xlabel('Temperature [K]')
ylabel('Fzero(SteadyStateTemp)')
xlim([Tdomain(1) Tdomain(end)]);
plot(Tdomain,Tzero, 'b')
plot(Tdomain,zeros(1,length(Tdomain)),'k');
hold off

Tguess(1)=290;     % Guess for the first steady-state as observed from the graph
Tguess(2)=320;     % Guess for the second steady-state as observed fromt the graph
Tguess(3)=370;     % Guess for the third steady-state as observed from the graph

for i=1:3
    fTsteady=@(Tguess)Tsteady(Tguess, T0, Tau, Ea, A, deltaHr, rhocp, Ca0);
    TempSteady(i)=fzero(fTsteady, Tguess(i));
end    

%TempSteady(1)=fzero(@Tsteady, Tguess(1));      % First steady-state
%TempSteady(2)=fzero(@Tsteady, Tguess(2));      % Second steady-state
%TempSteady(3)=fzero(@Tsteady, Tguess(3));      % Third steady-state

alfa(1:3)=A*exp(-Ea/Rgas./TempSteady(1:3)).*Tau;

Ca(1:3)=(-1+sqrt(1+4.*alfa(1:3).*Ca0))./(2.*alfa(1:3));

Conv(1:3)=(Ca0-Ca(1:3))/Ca0*100;

%Open the command prompt of Matlab to read the results
for i=1:3
    fprintf('Theoretical steady-state %i is at %.1f K and the reactants conversion is %.2f%%\n',i, TempSteady(i), Conv(i));
end

fprintf('\nSteady-state 2 is numerically unstable, for this reason, only the first and the third ones are observed.\n\n');