clear all 
close all 
clc

% CO H2O CO2 H2 N2

epsilon=.55;        % porosity 
Tau=2;              % tortuosity 
rhop=1.55E6;        % catalyst particle density g/m3
Rgas=8.314;         % universal gas constant J/mol/K
P0=1E5;             % pressure Pa
Rc=3.2E-3;          % spherical particle radius

y0=[.07 .5 .03 .2 .2];          % inlet mole fraction CO H2O CO2 H2 N2
T0=[663 683 703 723];
n=200;                          % number of divisions in the interval

for i=1:length(T0)

C0=(P0.*y0)./(Rgas*T0(i));              % inlet concentration of CO H2O CO2 H2       

xspan=linspace(1E-10,1,n);              % particle dimensionless length domain. IMPORTANT NOTE: this interval CANNOT start from ZERO because it would lead to division by ZERO in the term 2/x*dC/dx

SurfCond=C0;

% NOTE: Advantage of the Levenberg-Marquardt algorithm: it is faster and
% more efficient than others for this type of problem
% NOTE: Disadvantage of the Levenberg-Marquardt algorithm: it does not
% accept lower and upper bounds in the variable, therefore, you must always
% check the solution bounds yourself 

options = optimoptions(@fsolve,'TolX', 1E-12, 'Algorithm', 'levenberg-marquardt');
fInit=@(ZeroCond)Init(ZeroCond, T0(i), xspan, SurfCond, rhop, Rc);
InitCond=fsolve(fInit, SurfCond/2, options);

[x,c]=ode23s(@ddt, xspan, [zeros(1,5) InitCond], [], T0(i), rhop, Rc);
% the solution matrix 'c' has the following form: lines correspond to
% different positions and columns correpond to different compounds 
% This must be reconsidered when using functions such as 'Integral' and
% 'RateCalc'.

aux=c.';
num=Integral(aux(6:end,:),n,T0(i), xspan);
den=RateCalc(C0.', T0(i));
EffectFact=num./den;
Neta(i)=EffectFact(i);

figure(i) 
hold on
plot(x, c(:,6:end))
xlabel('Dimensionless Radius')
ylabel('Concentration [mol/m^3]')
title(['Concentration Profile @',num2str(T0(i)),'K'])
TextBox={'CO', 'H_2O', 'CO_2', 'H_2', 'N_2'};
legend(TextBox)
hold off

end

clc             % clears matlab command window before printing the results 
for i=1:length(T0)
    EffecDiff=DiffC(T0(i), P0/1E5, y0);
    fprintf('Equilibrium Effectiveness Factor @%iK= %.4f\n', T0(i), Neta(i));
    fprintf('Irreversible Effectiveness Factor @%iK= %.4f\n\n', T0(i), TheorNeta(Rc, rhop, EffecDiff(1), T0(i)))
end