close all
clear all
clc

% this code may take several minutes to compile. Be patient :) 
% CO H2O CO2 H2 N2

epsilon=.55;        % porosity 
Tau=2;              % tortuosity 
rhop=1.55E6;        % catalyst particle density g/m3
Rgas=8.314;         % universal gas constant J/mol/K
P0=1E5;             % pressure Pa
Rc=3.2E-3;          % spherical particle radius

y0=[.07 .5 .03 .2 .2];          % inlet mole fraction CO H2O CO2 H2 N2
T0=[663 683 703 723];
n=200;                          % number of discretization nodes

for i=1:length(T0)

C0=(P0.*y0)./(Rgas*T0(i));              % inlet concentration of CO H2O CO2 H2           

xspan=linspace(0,1,n);                  % particle dimensionless length domain

SurfCond=C0;                            % conditions on catalyst surface

InitGuess=ones(5,n);                    % initial guess of concentration profile

fPrfCalc=@(C)PrfCalc(C, n, SurfCond, rhop, Rc, T0(i), xspan);
Prf=fsolve(fPrfCalc, InitGuess); 

num=Integral(Prf, n, T0(i), xspan);     % the code calculates the effectiveness factor for all compounds
den=RateCalc(C0.', T0(i));              % separately, but, as you can see in the variable EffectFact, the   
EffectFact=num./den;                    % effectiveness factor is the same for all compounnds
Neta(i)=EffectFact(1);

figure(i) 
hold on
plot(xspan, Prf);
xlabel('Dimensionless Radius')
ylabel('Concentration [mol/m^3]')
title(['Concentration Profile @',num2str(T0(i)),'K'])
TextBox={'CO', 'H_2O', 'CO_2', 'H_2', 'N_2'};
legend(TextBox)
hold off

end

clc             % clears matlab command window before printing the results 
for i=1:length(T0)
    EffecDiff=DiffC(T0(i), P0/1E5, y0);
    fprintf('Effectiveness Factor @%iK= %.4f\n', T0(i), Neta(i));
    fprintf('First order Effectiveness Factor @%iK= %.4f\n\n', T0(i), TheorNeta(Rc, rhop, EffecDiff(1), T0(i)))
end