function result=PrfCalc(C, n, SurfCond, rhop, Rc, T, xspan)
% This function receives a matrix with the concentration profile in such a way that 
% the lines correspond to different compounds and the columns correspond to different 
% positions. This function returns a matrix with the residuals of the concentration 
% profile calculated and the concentration profile provided. In the output matrix, 
% the lines correspond to different compounds and the columns correspond to different positions

deltax=1/(n-1);

result(:,n)=C(:,n)-SurfCond.';              % boundary condition at the catalyst surface
result(:,1)=-3*C(:,1)+4*C(:,2)-C(:,3);      % boundary condition at the catalyst centre (3 points forward difference formula)

RatePrf=RateCalc(C,T);

% for the middle part of the catalyst, the 2 points central difference
% formula was applied to the first order derivative and the 3 points 
% central difference formula to the second order derivative

P0=1E5;

for i=2:n-1
    y0=C(:,i)/sum(C(:,i));
    D=DiffC(T, P0/1E5, y0.');       % calculates the diffusion coefficient at each position inside the particle
    D=D.';
    result(:,i)=(C(:,i-1)-2*C(:,i)+C(:,i+1))./deltax^2+2./xspan(i).*(C(:,i+1)-C(:,i-1))./(2*deltax)+RatePrf(:,i).*rhop.*Rc^2./D;
end

end