function rhs=ddt(x,c, T, rhop, Rc)
% the differential equation
% d2Ci/dx2=-2/x*dCi/dx-ri*rhop*Rc^2/Dei
% has its order lowered by the following transformation
% dCi/dx=hi
% dhi/dx=-2/x*hi-ri*rhop*Rc^2/Dei
% This function returns the solutions for this highly non-linear ODE system

Rgas=8.314;
P0=1E5;

cCO=c(6);
cH2O=c(7);
cCO2=c(8);
cH2=c(9);
cN2=c(10);

SM=[-1 -1 1 1 0];

A=95.02;                % pre-exponential factor in m3/g/s
Ea=94.3E3;              % activation energy J/mol
k=A*exp(-Ea/Rgas/T);    % rate constant m3/g/s
K=exp(4577.8/T-4.33);
B=cCO2*cH2/(K*cCO*cH2O);
rate=k*cCO*(1-B);

y=c(6:10)/sum(c(6:10));
D=DiffC(T, P0/1E5, y);      % calculation of the local diffusion coefficient for all compounds in m2/s
D=D.';              

rhs(1:5,1)=-2./x.*c(1:5,1)-SM.'*rate.*rhop.*Rc.^2./D(1:5);
rhs(6:10,1)=c(1:5,1);

end