% in order to solve exercise VI, you should do as follows
% to solve for item b), set mcat1=0 and mcat2=0
% to solve for item c), set mcat1=120 and mcat2=120
% to solve for item d), set mcat1=0 and mcat2=120

clear all 
close all 
clc

n=50;           % number of space-time studied between 0 and 500 minutes 
cFe2o=2;        % initial concentration of Fe (II) in mol/L
cSO4=cFe2o;     % concentration of sulfate in mol/L (sulfate is an spectator ion, meaning, it is present in the system but it does not react)

% Data for reactor 1
Tau1=500;                           % reactor 1 maximum space-time in minutes
TauSpan1=linspace(0,Tau1,n);        % space-times of reactor 1 in minutes
Temp1=100;                          % temperature in first reactor Celsius degrees
Temp1=Temp1+273.15;                 % converting temperature to Kelvin 
P1=3.5;                             % pressure in reactor 1 in atmospheres
mcat1=0;                            % catalyst mass in reactor 1 
VL1=1000;                           % reactor 1 volume in liters

% Data for reactor 2
Tau2=500;                           % reactor 2 maximun space-time in minutes
TauSpan2=linspace(0,Tau2,n);        % space-times reactor 2 in minutes
Temp2=100;                          % temperature in second reactor Celsius degrees
Temp2=Temp2+273.15;                 % converting temperature to Kelvin
P2=3.5;                             % pressure in reactor 2 in atmospheres
mcat2=120;                            % catalyst mass in reactor 2
VL2=1000;                           % reactor 2 volume in liters

% Sequence: Fe2 Fe3
Cin=[cFe2o 0];                  % inlet concentrations in mol/L 
Cguess=[cFe2o cFe2o]*.5;        % initial guess of outlet concentrations concentrations mol/L

for i=1:n
    fObjFun1=@(Cout1)ObjFun(Cout1, Cin, cSO4, TauSpan1(i), mcat1, VL1, Temp1, P1);
    Conc1(i,:)=fsolve(fObjFun1, Cguess);
    
    fObjFun2=@(Cout2)ObjFun(Cout2, Conc1(i,:), cSO4, TauSpan2(i), mcat2, VL2, Temp2, P2);
    Conc2(i,:)=fsolve(fObjFun2, Cguess);
end

Conv1=(cFe2o-Conc1(:,1))./cFe2o*100;            % conversion of Fe(II) in percentage in the first reactor
Conv2=(Conc1(:,1)-Conc2(:,1))./Conc1(:,1)*100;  % conversion of Fe(II) in percentage in the second reactor
ConvGlobal=(cFe2o-Conc2(:,1))./cFe2o*100;       % global conversion of Fe(II)

MaxVal=max(ConvGlobal);

if MaxVal<95
    fprintf('\nRequired conversion not satisfied\n');
    fprintf('Maximun global conversion= %.2f%%\n', MaxVal);
else
    for i=1:n
        if ConvGlobal(i)>95
            fprintf('\nGlobal space-time (95%% global conversion)= %.2f min\n', TauSpan1(i)+TauSpan2(i));
            break;
        end 
    end
end

hold on
plot(TauSpan1,Conc1, TauSpan2, Conc2)
title('Concentration vs. Space-time (First reactor)')
xlabel('Space-time [min]')
ylabel('Concentration [mol/L]')
TextBox1={'Fe^2^+ (Reactor 1)','Fe^3^+ (Reactor 1)', 'Fe^2^+ (Reactor 2)', 'Fe^3^+ (Reactor 2)'};
legend(TextBox1) 
hold off

figure 
hold on
plot(TauSpan1, Conv1, TauSpan2, Conv2, TauSpan1+TauSpan2, ConvGlobal)
title('Conversion vs. Space-time')
xlabel('Space-time [min]')
ylabel('Conversion [%]')
TextBox2={'First reactor','Second reactor', 'Global conversion'};
legend(TextBox2) 
hold off