% this code demands quite some memory from computer and may cause Matlab to
% crash during the compilation. If so, try to run this code in a different
% machine. In addition, by the end of this code you may find the section where 
% it creates an 'avi' video showing the dynamic behavior of the
% intraparticle concentration profiles

clear all 
close all 
clc

epsP=.5;
Tau=4;

timespan=linspace(0,8*3600, 5001);     % timespan in seconds

cT0=9.5E3;      % Initial concentration of toluene in liquid phase mol/m^3
cH0=0;          % Initial concentration of hydrogen in liquid phase mol/m^3
cMCH0=0;        % Initial concentration of MCH in liquid phase mol/m3

% This code contains all the options to solve items a-d
% For instance, in order to get the answer to item: 
% a) set kLa=[0; 1E5; 0] and Rc=1E-8 
% b) set kLa=[0; 0.05; 0] and Rc=1E-8
% c) set kLa=[0; .05; 0] and Rc=2E-4
% d) set kLa=[0; 1E5; 0] and Rc=2E-4
% the plot in item e) is left as an exercise to the student :) 

kLa=[0; 0.05; 0];    % gas-liquid mass transfer coefficient matrix [s^-1]
Rc=2E-4;            % particle radius [m]
D=[5E-11 4.4E-9 5E-11];     % in m^2/s
D=epsP/Tau.*D;              % m^2/s

n=100;               % number of equidistants discretization points inside catalyst particle

xspan=linspace(0,1,n);
InitTPart=cT0*ones(1,n);        % initial concentration of Toluene inside the particle
InitHPart=zeros(1,n);           % initial concentration of Hydrogen inside the particle
InitMCHPart=zeros(1,n);         % initial concentration of MCH inside the particle

InitLiqPhase=[cT0 cH0 cMCH0];                                % liquid phase initial conditions
Init0=[InitLiqPhase InitTPart InitHPart InitMCHPart];        % conditions at time zero of liquid phase and solid particle

[t,c]=ode23s(@ddt, timespan, Init0, [], n, kLa, Rc, D, epsP);

figure 
hold on
plot(t/60,c(:,1)/1000,'r',t/60,c(:,2)/1000,'b', t/60,c(:,3)/1000,'k');
xlim([0 t(end)/60]);
xlabel('Time [min]')
ylabel('Concentration [mol/L]')
title('Liquid phase concentrations')
TextBox1={'Toluene', 'H_2', 'Methylcyclohexane'};
legend(TextBox1)
hold off

figure
hold on 
plot(t/60,c(:,2)/1000)
xlim([0 t(end)/60]);
xlabel('Time [min]')
ylabel('Concentration [mol/L]')
title('Hydrogen concentration in liquid phase')
TextBox2={'Hydrogen'};
legend(TextBox2)
hold off

Conv=(cT0-c(:,1))./cT0*100;         % liquid phase conversion
for i=1:length(t)
   if Conv(i)>99
       fprintf('Time(99%% Conversion)= %.2f min\n\n', t(i)/60);
       break
   end
end

figure 
hold on 
plot(t/60,Conv)
xlim([0 t(end)/60]);
xlabel('Time [min]')
ylabel('Conversion [%]')
title('Liquid phase conversion vs. time')
TextBox4={'Conversion'};
legend(TextBox4)
hold off

% section of the code that creates the video. If you do not wish to have
% the video, just transform the following code in a comment. Try using the
% commands %{ %}

count=0;
figure 
for i=1:19:length(timespan)
    count=count+1;
    clf
    hold on
    plot(xspan, c(i,4:n+3)/1000, 'r',xspan, 50*c(i, n+4:2*n+3)/1000,'b', xspan, c(i, 2*n+4:3*n+3)/1000,'k')
    xlim([0 1])
    ylim([0 cT0*1.1/1000])
    str = sprintf('Intraparticle concentration at = %.2f min',timespan(i)/60);
    title(str);
    TextBox5={'T', '50x H_2', 'TH'};
    legend(TextBox5)
    xlabel('Dimensionless length coordinate')
    ylabel('Concentration [mol/L]')
    drawnow
    F(count)=getframe(gcf);
  end

video=VideoWriter('IntraParticleConc.avi', 'Uncompressed AVI');
open(video);
writeVideo(video,F);
close(video);